# TODO list

Needed a better place to organize my thoughts.

- [x] finish CA view and test
- [x] check discounting and add features/metrics
- [] add https://stackoverflow.com/a/28287730/155406 for status updates
- [] tests of base classes
- 
- [] [STARTED] consider a master view that has metrics flattened (1 row per like cip codes, enrollment by state, etc.)
- [] check docs
- [] update README for views and tutorial
- [] post package for initial release with flit or equivalent
- [] queue up a few posts (migration viz, forecasting with WICHE, degree completion share viz, cluster flattened view)
- [] add viz module
- [] go back on older surveys farther than standard naming syntax (hd is older than 2002)